@@ -75,11 +75,6 @@ class TcConnection:
         TcSoaBasics.logout()
 
 
-def asd():
-    with TcConnection('http://my.teamcenter:7001/tc', 'dcproxy', 'dcproxy') as f:
-        pass
-
-
 class TcSoaBasics:
     NULLTAG = 'AAAAAAAAAAAAAA'
 
