@@ -1,5 +1,5 @@
 from tcsoa.gen.ActiveWorkspaceVis._2015_03.services import DataManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DataManagementService(TcService):
