@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from tcsoa.gen.Bom._2010_09.StructureManagement import TraversedObjectsResponse, ObjectCoverageInput, TraversedObjectsInput, ObjectCoverageResponse
-from tcsoa.utils import TcService
+from tcsoa.gen.Bom._2010_09.StructureManagement import ObjectCoverageResponse, ObjectCoverageInput, TraversedObjectsResponse, TraversedObjectsInput
+from tcsoa.base import TcService
 
 
 class StructureManagementService(TcService):
