@@ -3,7 +3,7 @@ from __future__ import annotations
 from tcsoa.gen.BusinessObjects import BusinessObject, ImanFile, VariantRule
 from typing import Dict, List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 from datetime import datetime
 
