@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import POM_object, ItemRevision, MECfgLine, IncrementalChangeElement
+from tcsoa.gen.BusinessObjects import IncrementalChangeElement, MECfgLine, POM_object, ItemRevision
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
