@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.UiConfig._2014_11.UiConfig import ScopeInput, ColumnConfig
+from tcsoa.gen.UiConfig._2014_11.UiConfig import ColumnConfig, ScopeInput
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
