@@ -1,7 +1,7 @@
 from tcsoa.gen.Internal_ActiveWorkspaceVis._2015_03.services import MassiveModelVisualizationService as imp0
 from tcsoa.gen.Internal_ActiveWorkspaceVis._2018_05.services import MassiveModelVisualizationService as imp1
 from tcsoa.gen.Internal_ActiveWorkspaceVis._2014_11.services import OccurrenceManagementService as imp2
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class MassiveModelVisualizationService(TcService):
