@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.Translation._2007_06.TranslationManagement import CreateDatasetOfVersionResponse, CreateDatasetOfVersionArgs, InsertDatasetVersionArgs, QueryTranslationRequestsArgs, UpdateTranslationRequestResponse, UpdateTranslationRequestArgs, InsertDatasetVersionResponse, QueryTranslationRequestsResponse
+from tcsoa.gen.Internal.Translation._2007_06.TranslationManagement import CreateDatasetOfVersionArgs, QueryTranslationRequestsArgs, QueryTranslationRequestsResponse, CreateDatasetOfVersionResponse, InsertDatasetVersionArgs, UpdateTranslationRequestResponse, UpdateTranslationRequestArgs, InsertDatasetVersionResponse
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class TranslationManagementService(TcService):
