@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import List
 from tcsoa.gen.Internal.UiConfig._2014_11.UiConfig import ResetUIConfigInput, ResetUIConfigResponse
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class UiConfigService(TcService):
