@@ -1,8 +1,8 @@
 from __future__ import annotations
 
 from typing import List
-from tcsoa.gen.Participant._2018_11.Participant import ParticipantInfo, ParticipantResponse, ReassignParticipantInfoInput, ParticipantInfoInput, ReassignParticipantResponse
-from tcsoa.utils import TcService
+from tcsoa.gen.Participant._2018_11.Participant import ParticipantInfoInput, ParticipantInfo, ReassignParticipantResponse, ReassignParticipantInfoInput, ParticipantResponse
+from tcsoa.base import TcService
 
 
 class ParticipantService(TcService):
